# Generated by Django 4.2.15 on 2025-05-05 11:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0015_alter_corpinvoice_tax_reason'),
        ('corptax', '0015_discordnotification'),
    ]

    operations = [
    ]
