# Generated by Django 4.2.16 on 2025-05-03 11:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0014_troikavie_alter_adminview_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='DiscordNotification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_sent', models.BooleanField(default=False, help_text='True when this notification has been sent to Discord', verbose_name='is sent')),
                ('owner', models.IntegerField(help_text='Owner of the message', verbose_name='owner')),
                ('time_sent', models.DateTimeField(default=True, help_text='The time when the message has been sent')),
                ('discord_msg', models.CharField(help_text='The message what been sent to Discord', max_length=128, verbose_name='discord_msg')),
            ],
        ),
    ]
