# Generated by Django 4.2.15 on 2024-09-27 10:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0002_corpinvoice'),
    ]

    operations = [
        migrations.CreateModel(
            name='AdminView',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('admin_access', 'Can view Corp Taxes'),),
                'managed': False,
                'default_permissions': (),
            },
        ),
    ]
