# Generated by Django 4.2.15 on 2024-12-06 12:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0011_alter_alliancefinance_expense_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='alliancefinance',
            name='planatary_income',
        ),
    ]
