# Generated by Django 4.2.15 on 2025-05-30 07:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0016_merge_20250505_1148'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Invoice',
        ),
        migrations.DeleteModel(
            name='TaxPreview',
        ),
    ]
