# Generated by Django 4.2.15 on 2024-12-06 12:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0010_alliancefinance'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alliancefinance',
            name='expense',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=20, null=True, verbose_name='expense'),
        ),
        migrations.AlterField(
            model_name='alliancefinance',
            name='income',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=20, null=True, verbose_name='income'),
        ),
    ]
