# Generated by Django 4.2.15 on 2025-05-02 07:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0014_troikavie_alter_adminview_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='corpinvoice',
            name='tax_reason',
            field=models.CharField(max_length=128, verbose_name='tax_reason'),
        ),
    ]
