{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Corp Taxes" %}
{% endblock %}

{% block header_nav_brand %}
    {% translate "Corp Taxes" %}
{% endblock header_nav_brand %}

{% block content %}
    <div class="corptax">
        {% block details %}{% endblock %}
    </div>
{% endblock %}
