# Generated by Django 4.2.15 on 2024-09-28 11:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0003_adminview'),
    ]

    operations = [
        migrations.CreateModel(
            name='Invoice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('corp_id', models.BigIntegerField(verbose_name='corp_id')),
                ('date', models.DateField(verbose_name='date')),
            ],
        ),
        migrations.CreateModel(
            name='MoonLedgerMember',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('corp_id', models.BigIntegerField(verbose_name='corp_id')),
                ('character_id', models.BigIntegerField(verbose_name='character_id')),
                ('date', models.DateField(verbose_name='date')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=20, verbose_name='Amount')),
            ],
        ),
    ]
