# Generated by Django 4.2.15 on 2024-11-23 17:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0008_corpstats_corp_name_corpstats_total_member'),
    ]

    operations = [
        migrations.AddField(
            model_name='corpstats',
            name='alliance_id',
            field=models.BigIntegerField(null=True, verbose_name='corp_id'),
        ),
    ]
