# Generated by Django 4.2.15 on 2024-09-23 17:14

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='General',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('basic_access', 'Can access this app'),),
                'managed': False,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TaxPreview',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=20, verbose_name='Amount')),
                ('corp_name', models.CharField(max_length=128, verbose_name='CorpName')),
                ('tax_reason', models.CharField(max_length=128, verbose_name='CorpName')),
                ('corp_id', models.BigIntegerField(verbose_name='corp_id')),
                ('tax_date', models.DateField(verbose_name='tax_date')),
            ],
            options={
                'verbose_name': 'Corp Tax',
                'verbose_name_plural': 'Corp Taxes',
                'ordering': ['corp_name'],
            },
        ),
    ]
