# Generated by Django 4.2.15 on 2024-12-07 11:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0012_remove_alliancefinance_planatary_income'),
    ]

    operations = [
        migrations.AddField(
            model_name='alliancefinance',
            name='description',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='reason'),
        ),
    ]
