# Generated by Django 4.2.15 on 2024-12-06 11:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0009_corpstats_alliance_id'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllianceFinance',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField(verbose_name='date')),
                ('planatary_income', models.DecimalField(decimal_places=2, max_digits=20, verbose_name='planatary_income')),
                ('income', models.DecimalField(decimal_places=2, max_digits=20, verbose_name='income')),
                ('expense', models.DecimalField(decimal_places=2, max_digits=20, verbose_name='expense')),
                ('reason', models.CharField(max_length=128, verbose_name='reason')),
            ],
        ),
    ]
