# Generated by Django 4.2.15 on 2024-09-27 08:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CorpInvoice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=20, verbose_name='Amount')),
                ('corp_name', models.CharField(max_length=128, verbose_name='CorpName')),
                ('tax_reason', models.CharField(max_length=128, verbose_name='CorpName')),
                ('corp_id', models.BigIntegerField(verbose_name='corp_id')),
                ('tax_date', models.DateField(verbose_name='tax_date')),
            ],
        ),
    ]
