# Generated by Django 4.2.15 on 2024-11-21 11:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0007_alter_corpstats_corp_tax'),
    ]

    operations = [
        migrations.AddField(
            model_name='corpstats',
            name='corp_name',
            field=models.CharField(max_length=128, null=True, verbose_name='CorpName'),
        ),
        migrations.AddField(
            model_name='corpstats',
            name='total_member',
            field=models.IntegerField(blank=True, null=True, verbose_name='total_member'),
        ),
    ]
