# Generated by Django 4.2.15 on 2024-11-17 00:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0006_corpstats'),
    ]

    operations = [
        migrations.AlterField(
            model_name='corpstats',
            name='corp_tax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='corp_tax'),
        ),
    ]
