# Generated by Django 4.2.15 on 2024-11-16 14:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptax', '0005_moonledgermember_character_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='CorpStats',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('corp_id', models.BigIntegerField(verbose_name='corp_id')),
                ('auth_member', models.IntegerField(blank=True, null=True, verbose_name='auth_member')),
                ('audit_member', models.IntegerField(blank=True, null=True, verbose_name='audit_member')),
                ('auth_ceo', models.IntegerField(blank=True, null=True, verbose_name='auth_ceo')),
                ('corp_tax', models.DecimalField(blank=True, decimal_places=2, max_digits=3, null=True, verbose_name='corp_tax')),
                ('corp_journal', models.IntegerField(blank=True, null=True, verbose_name='corp_journal')),
            ],
        ),
    ]
